@@ -165,7 +165,7 @@ class TC2Env(Env):  # type: ignore
             if done:
                 logger.log(logging.INFO, 'Episode complete. Rewards: ' + str(rew))
         self.action_space = self.get_action_space(observation)
-        return observation, reward, done, {}
+        return observation, rew, done, {}
 
     def reset(self) -> None:
         """
